@@ -18,9 +18,7 @@ package Apache2::Reload;
 use strict;
 use warnings FATAL => 'all';
 
-use mod_perl2;
-
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Apache2::Const -compile => qw(OK);
 
@@ -360,7 +358,7 @@ mode described before.
 
 =head2 Unregistering a module
 
-In some cases, it might be necessary to explicitely stop reloading
+In some cases, it might be necessary to explicitly stop reloading
 a module.
 
   Apache2::Reload->unregister_module('Some::Module');
