@@ -33,7 +33,7 @@ sub strip_quotes {
 
 my %wanted_config = (
     TAKE1 => {map { $_, 1 } qw(ServerRoot ServerAdmin TypesConfig DocumentRoot)},
-    TAKE2 => {map { $_, 1 } qw(LoadModule)},
+    TAKE2 => {map { $_, 1 } qw(LoadModule LoadFile)},
 );
 
 my %spec_init = (
@@ -46,6 +46,7 @@ my %spec_apply = (
     ServerRoot  => sub {}, #dont override $self->{vars}->{serverroot}
     DocumentRoot => \&inherit_directive_var,
     LoadModule  => \&inherit_load_module,
+    LoadFile    => \&inherit_load_file,
 );
 
 #where to add config, default is preamble
@@ -180,7 +181,9 @@ my %modname_alias = (
 #skip it for now, tomcat has its own test suite anyhow.
 #XXX: mod_casp2.so requires other settings in addition to LoadModule
 #XXX: mod_bwshare.so blocks fast requests that tests are doing
-my @autoconfig_skip_module = qw(mod_jk.c mod_casp2.c mod_bwshare.c);
+#XXX: mod_fcgid.so causes https://rt.cpan.org/Public/Bug/Display.html?id=54476
+my @autoconfig_skip_module = qw(mod_jk.c mod_casp2.c mod_bwshare.c
+    mod_fcgid.c);
 
 # add modules to be not inherited from the existing config.
 # e.g. prevent from LoadModule perl_module to be included twice, when
@@ -247,6 +250,32 @@ sub inherit_load_module {
     }
 }
 
+#inherit LoadFile
+sub inherit_load_file {
+    my($self, $c, $directive) = @_;
+
+    for my $args (@{ $c->{$directive} }) {
+        my $file = $self->server_file_rel2abs($args->[0]);
+
+        unless (-e $file) {
+            debug "$file does not exist, skipping LoadFile";
+            next;
+        }
+
+        if ($self->should_skip_module($args->[0])) {
+            debug "Skipping LoadFile of $args->[0]";
+            next;
+        }
+
+        # remember all found modules
+        push @{$self->{load_file}}, $file;
+
+        debug "LoadFile $file";
+
+        $self->preamble_first(qq{LoadFile "$file"\n});
+    }
+}
+
 sub parse_take1 {
     my($self, $c, $directive) = @_;
     $c->{$directive} = strip_quotes;
