@@ -1,8 +1,9 @@
-# Copyright 2001-2005 The Apache Software Foundation
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -103,7 +104,7 @@ unless (defined $ModPerl::RegistryCooker::NameWithVirtualHost) {
 #########################################################################
 
 sub new {
-    my($class, $r) = @_;
+    my ($class, $r) = @_;
     my $self = bless {}, $class;
     $self->init($r);
     return $self;
@@ -325,7 +326,7 @@ sub make_namespace {
 sub namespace_from_filename {
     my $self = shift;
 
-    my ($volume, $dirs, $file) = 
+    my ($volume, $dirs, $file) =
         File::Spec::Functions::splitpath($self->{FILENAME});
     my @dirs = File::Spec::Functions::splitdir($dirs);
     return join '_', grep { defined && length } $volume, @dirs, $file;
@@ -336,11 +337,11 @@ sub namespace_from_uri {
     my $self = shift;
 
     my $path_info = $self->{REQ}->path_info;
-    my $script_name = $path_info && $self->{URI} =~ /$path_info$/
+    my $script_name = $path_info && $self->{URI} =~ /\Q$path_info\E$/
         ? substr($self->{URI}, 0, length($self->{URI}) - length($path_info))
         : $self->{URI};
 
-    if ($ModPerl::RegistryCooker::NameWithVirtualHost && 
+    if ($ModPerl::RegistryCooker::NameWithVirtualHost &&
         $self->{REQ}->server->is_virtual) {
         my $name = $self->{REQ}->get_server_name;
         $script_name = join "", $name, $script_name if $name;
@@ -485,7 +486,7 @@ sub is_cached {
 sub should_compile_if_modified {
     my $self = shift;
     $self->{MTIME} ||= -M $self->{REQ}->my_finfo;
-    !($self->is_cached && 
+    !($self->is_cached &&
       $self->cache_table->{ $self->{PACKAGE} }{mtime} <= $self->{MTIME});
 }
 
@@ -545,9 +546,8 @@ sub read_script {
             return Apache2::Const::FORBIDDEN if APR::Status::is_EACCES($@);
             return Apache2::Const::NOT_FOUND if APR::Status::is_ENOENT($@);
         }
-        else {
-            return Apache2::Const::SERVER_ERROR;
-        }
+
+        return Apache2::Const::SERVER_ERROR;
     }
 
     return Apache2::Const::OK;
@@ -575,7 +575,7 @@ my %switches = (
 
 sub shebang_to_perl {
     my $self = shift;
-    my($line) = ${ $self->{CODE} } =~ /^(.*)$/m;
+    my ($line) = ${ $self->{CODE} } =~ /^(.*)$/m;
     my @cmdline = split /\s+/, $line;
     return "" unless @cmdline;
     return "" unless shift(@cmdline) =~ /^\#!/;
@@ -610,14 +610,14 @@ sub get_script_name {
 # dflt: NOP
 # desc: chdirs into $dir
 # args: $self - registry blessed object
-#       $dir - a dir 
+#       $dir - a dir
 # rtrn: nothing (?or success/failure?)
 #########################################################################
 
 *chdir_file = \&NOP;
 
 sub chdir_file_normal {
-    my($self, $dir) = @_;
+    my ($self, $dir) = @_;
     $dir ||= File::Basename::dirname($self->{FILENAME});
     $self->debug("chdir $dir") if DEBUG & D_NOISE;
     chdir $dir or die "Can't chdir to $dir: $!";
@@ -662,7 +662,7 @@ sub strip_end_data_segment {
 #########################################################################
 
 sub compile {
-    my($self, $eval) = @_;
+    my ($self, $eval) = @_;
 
     $self->debug("compiling $self->{FILENAME}") if DEBUG && D_COMPILE;
 
@@ -670,9 +670,9 @@ sub compile {
     ModPerl::Global::special_list_clear(   END => $self->{PACKAGE});
 
     {
-        # let the code define its own warn and strict level 
+        # let the code define its own warn and strict level
         no strict;
-        no warnings FATAL => 'all'; # because we use FATAL 
+        no warnings FATAL => 'all'; # because we use FATAL
         eval $$eval;
     }
 
@@ -711,10 +711,10 @@ sub error_check {
 #########################################################################
 
 sub install_aliases {
-    my($class, $rh_aliases) = @_;
+    my ($class, $rh_aliases) = @_;
 
     no strict 'refs';
-    while (my($k,$v) = each %$rh_aliases) {
+    while (my ($k,$v) = each %$rh_aliases) {
         if (my $sub = *{$v}{CODE}){
             *{ $class . "::$k" } = $sub;
         }
@@ -733,7 +733,7 @@ sub debug {
 }
 
 sub log_error {
-    my($self, $msg) = @_;
+    my ($self, $msg) = @_;
     my $class = ref $self;
 
     $self->{REQ}->log_error($msg);
@@ -763,7 +763,7 @@ sub log_error {
 # cache_table() to point to another function, this function will fail.
 sub uncache_myself {
     my $package = scalar caller;
-    my($class) = __PACKAGE__->cache_table_common();
+    my ($class) = __PACKAGE__->cache_table_common();
 
     unless (defined $class) {
         Apache2->warn("$$: cannot figure out cache symbol table for $package");
