@@ -2,7 +2,7 @@
 
 # this test should return forbidden, since it should be not-executable
 
-print "Content-type: text/plain\r\n\r\n";
+print "Content-type: text/plain\n\n";
 print "ok";
 
 __END__
