@@ -1,8 +1,9 @@
-# Copyright 2000-2005 The Apache Software Foundation
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -67,7 +68,7 @@ my %hook_proto = (
     },
     PerSrv     => {
         ret  => 'int',
-        args => [{type => 'request_rec', name => 'r'}, 
+        args => [{type => 'request_rec', name => 'r'},
                  {type => 'dummy', name => 'MP_HOOK_RUN_ALL'}],
     },
     Connection => {
@@ -125,7 +126,7 @@ for my $class (qw(Process Connection PreConnection Files)) {
     }
 }
 
-while (my($k,$v) = each %directive_proto) {
+while (my ($k,$v) = each %directive_proto) {
     $directive_proto{$k}->{ret} = 'const char *';
     my $handlers = join '_', 'handlers', canon_lc($k);
     $directive_proto{$k}->{handlers} =
@@ -137,9 +138,9 @@ my @hook_flags = (map { canon_uc($_) } keys %hooks);
 my @ithread_opts = qw(CLONE PARENT);
 my %flags = (
     Srv => ['NONE', @ithread_opts, qw(ENABLE AUTOLOAD MERGE_HANDLERS),
-            @hook_flags, 'UNSET'],
+            @hook_flags, 'UNSET','INHERIT_SWITCHES'],
     Dir => [qw(NONE PARSE_HEADERS SETUP_ENV MERGE_HANDLERS GLOBAL_REQUEST UNSET)],
-    Req => [qw(NONE SET_GLOBAL_REQUEST PARSE_HEADERS SETUP_ENV 
+    Req => [qw(NONE SET_GLOBAL_REQUEST PARSE_HEADERS SETUP_ENV
                CLEANUP_REGISTERED PERL_SET_ENV_DIR PERL_SET_ENV_SRV)],
     Interp => [qw(NONE IN_USE PUTBACK CLONED BASE)],
     Handler => [qw(NONE PARSED METHOD OBJECT ANON AUTOLOAD DYNAMIC FAKE)],
@@ -168,9 +169,9 @@ sub new {
 sub path { shift->{path} }
 
 sub handler_desc {
-    my($self, $h_add, $c_add) = @_;
+    my ($self, $h_add, $c_add) = @_;
     local $" = ",\n";
-    while (my($class, $h) = each %{ $self->{handler_index_desc} }) {
+    while (my ($class, $h) = each %{ $self->{handler_index_desc} }) {
         my $func = canon_func('handler', 'desc', $class);
         my $array = join '_', 'MP', $func;
         my $proto = "const char *$func(int idx)";
@@ -192,11 +193,11 @@ EOF
 }
 
 sub generate_handler_index {
-    my($self, $h_fh) = @_;
+    my ($self, $h_fh) = @_;
 
     my $type = 1;
 
-    while (my($class, $handlers) = each %{ $self->{handlers} }) {
+    while (my ($class, $handlers) = each %{ $self->{handlers} }) {
         my $i = 0;
         my $n = @$handlers;
         my $handler_type = canon_define('HANDLER_TYPE', $class);
@@ -220,11 +221,11 @@ sub generate_handler_index {
 }
 
 sub generate_handler_hooks {
-    my($self, $h_fh, $c_fh) = @_;
+    my ($self, $h_fh, $c_fh) = @_;
 
     my @register_hooks;
 
-    while (my($class, $prototype) = each %{ $self->{hook_proto} }) {
+    while (my ($class, $prototype) = each %{ $self->{hook_proto} }) {
         my $callback = canon_func('callback', $class);
         my $return = $prototype->{ret} eq 'void' ? '' : 'return';
         my $i = -1;
@@ -243,7 +244,7 @@ sub generate_handler_hooks {
                   "    ap_hook_$hook($name, NULL, NULL, $order);";
             }
 
-            my($protostr, $pass) = canon_proto($prototype, $name);
+            my ($protostr, $pass) = canon_proto($prototype, $name);
             my $ix = $self->{handler_index}->{$class}->[$i];
 
             if ($callback =~ m/modperl_callback_per_(dir|srv)/) {
@@ -275,10 +276,10 @@ EOF
 }
 
 sub generate_handler_find {
-    my($self, $h_fh, $c_fh) = @_;
+    my ($self, $h_fh, $c_fh) = @_;
 
     my $proto = 'int modperl_handler_lookup(const char *name, int *type)';
-    my(%ix, %switch);
+    my (%ix, %switch);
 
     print $h_fh "$proto;\n";
 
@@ -292,7 +293,7 @@ $proto
     switch (*name) {
 EOF
 
-    while (my($class, $handlers) = each %{ $self->{handlers} }) {
+    while (my ($class, $handlers) = each %{ $self->{handlers} }) {
         my $i = 0;
 
         for my $name (@$handlers) {
@@ -334,11 +335,11 @@ EOF
 }
 
 sub generate_handler_directives {
-    my($self, $h_fh, $c_fh) = @_;
+    my ($self, $h_fh, $c_fh) = @_;
 
     my @cmd_entries;
 
-    while (my($class, $handlers) = each %{ $self->{handlers} }) {
+    while (my ($class, $handlers) = each %{ $self->{handlers} }) {
         my $prototype = $self->{directive_proto}->{$class};
         my $i = 0;
 
@@ -378,7 +379,7 @@ $protostr
                            "$h_name is disabled for server ",
                            parms->server->server_hostname, NULL);
     }
-    MP_TRACE_d(MP_FUNC, "push \@%s, %s\\n", parms->cmd->name, arg);
+    MP_TRACE_d(MP_FUNC, "push \@%s, %s", parms->cmd->name, arg);
     return $cmd_push(&($av), arg, parms->pool);
 }
 EOF
@@ -391,7 +392,7 @@ EOF
 }
 
 sub generate_flags {
-    my($self, $h_fh, $c_fh) = @_;
+    my ($self, $h_fh, $c_fh) = @_;
 
     my $n = 1;
 
@@ -399,7 +400,7 @@ sub generate_flags {
 
     print $h_fh "\n#define MP_SYS_$dlsrc 1\n";
 
-    while (my($class, $opts) = each %{ $self->{flags} }) {
+    while (my ($class, $opts) = each %{ $self->{flags} }) {
         my @lookup = ();
         my %lookup = ();
         my $lookup_proto = "";
@@ -450,7 +451,7 @@ EOF
             for (keys %lookup) {
                 if (/^(\w)/) {
                     my $gap = " " x ($max_len - length $_);
-                    push @{ $switch{$1} }, 
+                    push @{ $switch{$1} },
                         qq{if (strEQ(str, "$_"))$gap return $lookup{$_};};
                 }
             }
@@ -460,14 +461,14 @@ EOF
                 push @lookup, $indent1 . "  case '$_':";
                 push @lookup, map { $indent2 . $_ } @{ $switch{$_} };
             }
-            push @lookup, map { $indent1 . $_ } ("}\n", "return 0;\n}\n\n");
+            push @lookup, map { $indent1 . $_ } ("}\n", "return -1;\n}\n\n");
 
             print $c_fh join "\n", @lookup;
             print $h_fh "$lookup_proto;\n";
         }
 
         delete $dumper{None}; #NONE
-        print $h_fh join ' \\'."\n", 
+        print $h_fh join ' \\'."\n",
           "#define ${class}_dump_flags(p, str)",
                      qq{modperl_trace(NULL, "$class flags dump (%s):", str);},
                      map $dumper{$_}, sort keys %dumper;
@@ -499,7 +500,7 @@ my %trace = (
 );
 
 sub generate_trace {
-    my($self, $h_fh) = @_;
+    my ($self, $h_fh) = @_;
 
     my $v     = $self->{build}->{VERSION};
     my $api_v = $self->{build}->{API_VERSION};
@@ -551,7 +552,7 @@ EOF
         $i += $i;
     }
 
-    print $h_fh join ' \\'."\n", 
+    print $h_fh join ' \\'."\n",
                      '#define MP_TRACE_dump_flags()',
                      qq{modperl_trace(NULL, "mod_perl trace flags dump:");},
                      @dumper;
@@ -560,7 +561,7 @@ EOF
 }
 
 sub generate_largefiles {
-    my($self, $h_fh) = @_;
+    my ($self, $h_fh) = @_;
 
     my $flags = $self->perl_config('ccflags_uselargefiles');
 
@@ -568,7 +569,7 @@ sub generate_largefiles {
 
     for my $flag (split /\s+/, $flags) {
         next if $flag =~ /^-/; # skip -foo flags
-        my($name, $val) = split '=', $flag;
+        my ($name, $val) = split '=', $flag;
         $val ||= '';
         $name =~ s/^-D//;
         print $h_fh "#define $name $val\n";
@@ -619,8 +620,8 @@ sub canon_args {
 }
 
 sub canon_proto {
-    my($prototype, $name) = @_;
-    my($in,$pass) = canon_args($prototype);
+    my ($prototype, $name) = @_;
+    my ($in,$pass) = canon_args($prototype);
 
     local $" = ', ';
 
@@ -710,12 +711,12 @@ sub noedit_warning_hash {
 }
 
 sub init_file {
-    my($self, $name) = @_;
+    my ($self, $name) = @_;
 
     return unless $name;
     return if $self->{init_files}->{$name}++;
 
-    my(@preamble);
+    my (@preamble);
     if ($name =~ /\.h$/) {
         (my $d = uc $name) =~ s/\./_/;
         push @preamble, "#ifndef $d\n#define $d\n";
@@ -735,7 +736,7 @@ sub init_file {
 }
 
 sub fh {
-    my($self, $name) = @_;
+    my ($self, $name) = @_;
     return unless $name;
     $self->{fh}->{$name};
 }
@@ -749,7 +750,7 @@ sub postamble {
 }
 
 sub generate {
-    my($self, $build) = @_;
+    my ($self, $build) = @_;
 
     $self->{build} = $build;
 
@@ -760,10 +761,10 @@ sub generate {
     }
 
     for my $method (reverse sort keys %sources) {
-        my($h_fh, $c_fh) = map {
+        my ($h_fh, $c_fh) = map {
             $self->fh($sources{$method}->{$_});
         } qw(h c);
-        my($h_add, $c_add) = $self->$method($h_fh, $c_fh);
+        my ($h_add, $c_add) = $self->$method($h_fh, $c_fh);
         if ($h_add) {
             print $h_fh $h_add;
         }
@@ -778,6 +779,16 @@ sub generate {
     my $xsinit = "$self->{path}/modperl_xsinit.c";
     debug "generating...$xsinit";
 
+    # There's a possibility that $Config{static_ext} may contain spaces
+    # and ExtUtils::Embed::xsinit won't handle the situation right. In
+    # this case we'll get buggy "boot_" statements in modperl_xsinit.c.
+    # Fix this by cleaning the @Extensions array.
+
+    # Loads @Extensions if not loaded
+    ExtUtils::Embed::static_ext();
+
+    @ExtUtils::Embed::Extensions = grep{$_} @ExtUtils::Embed::Extensions;
+
     #create bootstrap method for static xs modules
     my $static_xs = [keys %{ $build->{XS} }];
     ExtUtils::Embed::xsinit($xsinit, 1, $static_xs);
@@ -788,7 +799,7 @@ sub generate {
 my $constant_prefixes = join '|', qw{APR? MODPERL_RC};
 
 sub generate_constants {
-    my($self, $h_fh, $c_fh) = @_;
+    my ($self, $h_fh, $c_fh) = @_;
 
     require Apache2::ConstantsTable;
 
@@ -809,9 +820,9 @@ my %shortcuts = (
 
 #backwards compat with older httpd/apr
 #XXX: remove once we require newer httpd/apr
-my %ifdef = map { $_, 1 } 
+my %ifdef = map { $_, 1 }
     qw(APLOG_TOCLIENT APR_LIMIT_NOFILE), # added in ???
-    qw(AP_MPMQ_STARTING AP_MPMQ_RUNNING AP_MPMQ_STOPPING 
+    qw(AP_MPMQ_STARTING AP_MPMQ_RUNNING AP_MPMQ_STOPPING
        AP_MPMQ_MPM_STATE), # added in 2.0.49
     qw(APR_FPROT_USETID APR_FPROT_GSETID
        APR_FPROT_WSTICKY APR_FOPEN_LARGEFILE); # added in 2.0.50?
@@ -827,16 +838,16 @@ sub constants_ifdef {
 }
 
 sub constants_lookup_code {
-    my($h_fh, $c_fh, $constants, $class) = @_;
+    my ($h_fh, $c_fh, $constants, $class) = @_;
 
-    my(%switch, %alias);
+    my (%switch, %alias);
 
     %alias = %shortcuts;
 
     my $postfix = canon_lc(lc $class);
     my $package = $class . '::';
     my $package_len = length $package;
-    my($first_let) = $class =~ /^(\w)/;
+    my ($first_let) = $class =~ /^(\w)/;
 
     my $func = canon_func(qw(constants lookup), $postfix);
     my $proto = "SV \*$func(pTHX_ const char *name)";
@@ -876,7 +887,7 @@ $ifdef[0]
           if (strEQ(name, "$name")) {
 EOF
 
-            if ($name eq 'DECLINE_CMD' || 
+            if ($name eq 'DECLINE_CMD' ||
                 $name eq 'DIR_MAGIC_TYPE' ||
                 $name eq 'CRLF') {
                 print $c_fh <<EOF;
@@ -906,9 +917,9 @@ EOF
 }
 
 sub generate_constants_lookup {
-    my($h_fh, $c_fh) = @_;
+    my ($h_fh, $c_fh) = @_;
 
-    while (my($class, $groups) = each %$Apache2::ConstantsTable) {
+    while (my ($class, $groups) = each %$Apache2::ConstantsTable) {
         my $constants = [map { @$_ } values %$groups];
 
         constants_lookup_code($h_fh, $c_fh, $constants, $class);
@@ -916,23 +927,23 @@ sub generate_constants_lookup {
 }
 
 sub generate_constants_group_lookup {
-    my($h_fh, $c_fh) = @_;
+    my ($h_fh, $c_fh) = @_;
 
-    while (my($class, $groups) = each %$Apache2::ConstantsTable) {
+    while (my ($class, $groups) = each %$Apache2::ConstantsTable) {
         constants_group_lookup_code($h_fh, $c_fh, $class, $groups);
     }
 }
 
 sub constants_group_lookup_code {
-    my($h_fh, $c_fh, $class, $groups) = @_;
+    my ($h_fh, $c_fh, $class, $groups) = @_;
     my @tags;
     my @code;
 
     $class = canon_lc(lc $class);
-    while (my($group, $constants) = each %$groups) {
-	push @tags, $group;
+    while (my ($group, $constants) = each %$groups) {
+        push @tags, $group;
         my $name = join '_', 'MP_constants', $class, $group;
-	print $c_fh "\nstatic const char *$name [] = { \n",
+        print $c_fh "\nstatic const char *$name [] = { \n",
           (map {
               my @ifdef = constants_ifdef($_);
               s/^($constant_prefixes)_?//o;
@@ -954,12 +965,12 @@ sub constants_group_lookup_code {
     print $c_fh "\n$proto\n{\n", "   switch (*name) {\n";
 
     for my $key (sort keys %switch) {
-	my $val = $switch{$key};
-	print $c_fh "\tcase '$key':\n";
-	for my $group (@$val) {
+        my $val = $switch{$key};
+        print $c_fh "\tcase '$key':\n";
+        for my $group (@$val) {
             my $name = join '_', 'MP_constants', $class, $group;
-	    print $c_fh qq|\tif(strEQ("$group", name))\n\t   return $name;\n|;
-	}
+            print $c_fh qq|\tif(strEQ("$group", name))\n\t   return $name;\n|;
+        }
         print $c_fh "      break;\n";
     }
 
@@ -974,7 +985,7 @@ EOF
 my %seen_const = ();
 # generates APR::Const and Apache2::Const manpages in ./tmp/
 sub generate_constants_pod {
-    my($self) = @_;
+    my ($self) = @_;
 
     my %data = ();
     generate_constants_group_lookup_doc(\%data);
@@ -1026,9 +1037,9 @@ EOF
 }
 
 sub generate_constants_lookup_doc {
-    my($data) = @_;
+    my ($data) = @_;
 
-    while (my($class, $groups) = each %$Apache2::ConstantsTable) {
+    while (my ($class, $groups) = each %$Apache2::ConstantsTable) {
         my $constants = [map { @$_ } values %$groups];
 
         constants_lookup_code_doc($constants, $class, $data);
@@ -1036,19 +1047,19 @@ sub generate_constants_lookup_doc {
 }
 
 sub generate_constants_group_lookup_doc {
-    my($data) = @_;
+    my ($data) = @_;
 
-    while (my($class, $groups) = each %$Apache2::ConstantsTable) {
+    while (my ($class, $groups) = each %$Apache2::ConstantsTable) {
         constants_group_lookup_code_doc($class, $groups, $data);
     }
 }
 
 sub constants_group_lookup_code_doc {
-    my($class, $groups, $data) = @_;
+    my ($class, $groups, $data) = @_;
     my @tags;
     my @code;
 
-    while (my($group, $constants) = each %$groups) {
+    while (my ($group, $constants) = each %$groups) {
         $data->{$class}{$group} = [
             map {
                 my @ifdef = constants_ifdef($_);
@@ -1061,9 +1072,9 @@ sub constants_group_lookup_code_doc {
 }
 
 sub constants_lookup_code_doc {
-    my($constants, $class, $data) = @_;
+    my ($constants, $class, $data) = @_;
 
-    my(%switch, %alias);
+    my (%switch, %alias);
 
     %alias = %shortcuts;
 
@@ -1095,7 +1106,7 @@ sub constants_lookup_code_doc {
 }
 
 sub generate_exports {
-    my($self, $c_fh) = @_;
+    my ($self, $c_fh) = @_;
     require ModPerl::WrapXS;
     ModPerl::WrapXS->generate_exports($c_fh);
 }
