@@ -1,8 +1,9 @@
-/* Copyright 2000-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -58,7 +59,7 @@ void modperl_apr_table_dump(pTHX_ apr_table_t *table, char *name)
                 len = tmp_len;
             }
         }
-    }    
+    }
     /* dump the table with keys aligned */
     fmt = Perl_form(aTHX_ "%%-%ds => %%s", len);
 
@@ -67,7 +68,7 @@ void modperl_apr_table_dump(pTHX_ apr_table_t *table, char *name)
             continue;
         }
         modperl_trace(MP_FUNC, fmt, elts[i].key, elts[i].val);
-    }    
+    }
     modperl_trace(MP_FUNC, "");
 }
 #endif
@@ -92,8 +93,7 @@ void modperl_perl_modglobal_dump(pTHX)
         MP_TRACE_g(MP_FUNC, "| %s => 0x%lx", key, val);
     }
 
-    MP_TRACE_g(MP_FUNC, "|-------- PL_modglobal --------\n");
+    MP_TRACE_g(MP_FUNC, "|-------- PL_modglobal --------");
 
 }
 #endif
-
