@@ -6,32 +6,32 @@ package TestHooks::push_handlers_blessed;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::RequestUtil ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::RequestUtil ();
 use APR::Table ();
 
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Const -compile => qw(OK DECLINED);
+use Apache2::Const -compile => qw(OK DECLINED);
 
 sub handler {
     my $r = shift;
 
-    plan $r, tests => 1, need_min_module_version('B::Deparse', 0.61);;
+    plan $r, tests => 1;
 
     my $sub = sub {
         ok 1;
 
-        return Apache::OK;
+        return Apache2::Const::OK;
     };
 
     my $handler = bless $sub, __PACKAGE__;
 
     $r->push_handlers(PerlResponseHandler => $handler);
 
-    return Apache::DECLINED;
+    return Apache2::Const::DECLINED;
 }
 
 1;
