@@ -9,24 +9,24 @@ use warnings FATAL => 'all';
 use Apache::TestUtil;
 use Apache::Test;
 
-use Apache::RequestRec ();
-use Apache::RequestUtil ();
-use Apache::Connection ();
+use Apache2::RequestRec ();
+use Apache2::RequestUtil ();
+use Apache2::Connection ();
 
-use Apache::Const -compile => qw(OK CONN_CLOSE);
+use Apache2::Const -compile => qw(OK CONN_CLOSE);
 
 sub handler {
     my $r = shift;
 
     my $c = $r->connection;
 
-    plan $r, tests => 14;
+    plan $r, tests => 16;
 
     ok $c;
 
     ok $c->pool->isa('APR::Pool');
 
-    ok $c->base_server->isa('Apache::ServerRec');
+    ok $c->base_server->isa('Apache2::ServerRec');
 
     ok $c->client_socket->isa('APR::Socket');
 
@@ -34,14 +34,26 @@ sub handler {
 
     ok $c->remote_addr->isa('APR::SockAddr');
 
-    ok $c->remote_ip;
+    # remote_ip
+    {
+        my $remote_ip_org = $c->remote_ip;
+        my $remote_ip_new = "10.10.10.255";
+        ok $remote_ip_org;
+
+        $c->remote_ip($remote_ip_new);
+        ok t_cmp $c->remote_ip, $remote_ip_new;
+
+        # restore
+        $c->remote_ip($remote_ip_org);
+        ok t_cmp $c->remote_ip, $remote_ip_org;
+    }
 
     ok $c->remote_host || 1;
 
     ok !$c->aborted;
 
     ok t_cmp($c->keepalive,
-             Apache::CONN_CLOSE,
+             Apache2::Const::CONN_CLOSE,
              "the client has issued a non-keepalive request");
 
     ok $c->local_ip;
@@ -56,7 +68,7 @@ sub handler {
     # XXX: missing tests
     # conn_config
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
