@@ -3,20 +3,22 @@ package TestApache::post;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
-use Apache::Const -compile => 'OK';
+use TestCommon::Utils ();
+
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
     $r->content_type('text/plain');
 
-    my $data = ModPerl::Test::read_post($r) || "";
+    my $data = TestCommon::Utils::read_post($r) || "";
 
     $r->puts(join ':', length($data), $data);
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
