@@ -3,10 +3,10 @@ package TestApache::write;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use constant BUFSIZ => 512; #small for testing
 
@@ -24,7 +24,7 @@ sub handler {
     $ok = "not ok 2\n";
     $r->write($ok, 5, 4);
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
