@@ -4,6 +4,7 @@ use strict;
 use warnings FATAL => 'all';
 
 use Apache::Test;
+use Apache::TestRequest;
 use Apache::TestUtil;
 use Apache2::Const -compile => 'OK';
 use Apache2::PerlSections;
@@ -11,7 +12,7 @@ use Apache2::PerlSections;
 sub handler {
     my $r = shift;
 
-    plan $r, tests => 15;
+    plan $r, tests => 22, need_module('mod_alias');
 
     ok t_cmp('yes', $TestDirective::perl::worked);
 
@@ -39,7 +40,9 @@ sub handler {
     # 3 would mean we are still counting lines from the context of the eval
     ok $TestDirective::perl::line > 3;
 
-    ok t_cmp($0, "-e", '$0');
+    ok !t_cmp($0, '-e', '$0');
+    my $target = Apache::Test::vars('target');
+    ok t_cmp($0, qr/$target/i, '$0');
 
     ok t_cmp($TestDirective::perl::Included, 1, "Include");
 
@@ -51,6 +54,21 @@ sub handler {
 
     ok t_cmp($TestDirective::perldo::test::Include, qr/perlsection.conf/);
 
+    #Check for correct Apache2::ServerUtil->server behavior
+    my $bport = $TestDirective::perl::base_server->port;
+    my $vport = $TestDirective::perl::vhost_server->port;
+    ok defined $bport && defined $vport && $vport != $bport;
+
+    foreach my $url (qw(scalar scalar1 scalar2)) {
+        my $res = GET "/perl_sections_perlconfig_$url/";
+        ok t_cmp($res->is_success, 1, '$PerlConfig');
+    }
+
+    foreach my $url (qw(array1 array2)) {
+        my $res = GET "/perl_sections_perlconfig_$url/";
+        ok t_cmp($res->is_success, 1, '@PerlConfig');
+    }
+
     Apache2::Const::OK;
 }
 
