@@ -9,11 +9,11 @@ use warnings FATAL => 'all';
 
 use Apache::Test ();
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 use File::Spec::Functions qw(catfile);
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -21,7 +21,7 @@ sub handler {
     $r->content_type('text/plain');
     $r->puts($ApacheTest::PerlModuleTest::MAGIC || '');
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 sub APACHE_TEST_CONFIGURE {
@@ -53,7 +53,7 @@ __END__
 <VirtualHost TestDirective::perlmodule>
     PerlModule ApacheTest::PerlModuleTest
 
-    <Location /TestDirective::perlmodule>
+    <Location /TestDirective__perlmodule>
         SetHandler modperl
         PerlResponseHandler TestDirective::perlmodule
     </Location>
