@@ -3,10 +3,10 @@ package TestError::syntax;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 sub handler {
     my $r = shift;
@@ -18,7 +18,7 @@ sub handler {
 
     $r->print('ok');
 
-    return Apache::OK;
+    return Apache2::Const::OK;
 }
 
 1;
